// File: LibTFT2p8.h
// Library for 2.8 inch TFT Resistive Touch Screen
// Allows Flip and Rotate
// 2015-09 jan@breem.nl

#ifndef LIBTFT2p8_H
#define LIBTFT2p8_H

#include "SimpleFont.h"

// #defines to be set per application
#define NUMBEROFTOUCHAREAS 10
//#define FLIPLEFTRIGHT
//#define FLIPUPDOWN
#define ROTATE

/*
Default Orientation: 
The screen has a resolution of 240 x 320 pixels.
When we hold the unit in portrait position with the SD-slot behind the lower left corner
 the X-Axis goes from right to left, and the Y axis from bottom to top.
#define FLIPLEFTRIGHT to have the X-axis go from left to right.
#define FLIPUPDOWN to have the Y-axis go from top to bottom.
#define ROTATE to exchange X- and Y-axis. Rotate the unit clockwise to landscape position with the  
  SD-slot behind the upper left corner, then the X-axis goes from left to right, and the Y from bottom to top.
Any combination of FLIPLEFTRIGHT, FLIPUPDOWN and ROTATE is allowed. But mind that they relate to the native coordinate system.

For "normal" portrait orientation use only FLIPLEFTRIGHT and hold the unit with the SD-slot behind the lower left corner. 
For "normal" landscape orientation use only ROTATE and hold the unit with the SD-slot behind the upper left corner.
*/

//******************************************************************************************************
// Select the properly oriented character map
#ifdef ROTATE  
  #ifdef FLIPUPDOWN
    #ifdef FLIPLEFTRIGHT
        #define SIMPLEFONT SimpleFontROTLR
    #else
        #define SIMPLEFONT SimpleFontROTUDLR
    #endif
  #else
    #ifdef FLIPLEFTRIGHT
        #define SIMPLEFONT SimpleFontROT
    #else
        #define SIMPLEFONT SimpleFontROTUD
    #endif
  #endif
#else
  #ifdef FLIPUPDOWN
    #ifdef FLIPLEFTRIGHT
        #define SIMPLEFONT SimpleFontLR
    #else
        #define SIMPLEFONT SimpleFontORG
    #endif
  #else
    #ifdef FLIPLEFTRIGHT
      #define SIMPLEFONT SimpleFontUDLR  
    #else
      #define SIMPLEFONT SimpleFontUD    
    #endif
  #endif
#endif

void tft_ClearScreen (void);

void tft_DrawLine (int X1, int Y1, int X2, int Y2, int Color);

void tft_DrawThickHorizontalLine (int X, int Y, int Length, int Thick, int Color);
// Thickens to the Y+ direction, Length goes to X+ direction

void tft_DrawThickVerticalLine (int X, int Y, int Length, int Thick, int Color);
// Thickens to the X+ direction, Length goes to the Y+ direction

void tft_DrawThickRectangle (int X, int Y, int Width, int Height, int Thick, int Color);
// Thickens to the inside. Width goes to the X+ direction, Heigth to Y+
// Negative values for Width or Height are not allowed 
  
void tft_DrawTriangle (int X1, int Y1, int X2, int Y2, int X3, int Y3, int Color);

void tft_DrawThickCircle (int X, int Y, int Diameter, int Thick, int Color);
// Thickens to the inside

void tft_DrawFilledCircle (int X, int Y, int Diameter, int Color);

void tft_DrawChar (char CH, int X, int Y, int Size, int fgColor, int bgColor);
// XY of char is lower left corner

void tft_DrawString (char *S, int X, int Y, int Size, int fgColor, int bgColor);
// XY of string is lower left corner of first char.

void tft_StoreTouchArea (int Xmin, int Ymin, int Xmax, int Ymax, void(*CallBackPtr)(void));

void tft_ClearTouchAreas (void);
// before drawing a new set of controls

int tft_DetectTouch (void); 
// Returns the AreaNumber of the area touched. 
// Calls the function allocated.
// If no touch returns -1 
// If touch is outside the declared regions 0 is returned

void tft_init_LibTFT2p8(void);

#endif
